@@ -52,11 +52,16 @@ class MetricReference(object):
 
 
 def _get_measures_timeserie(storage, ref, granularity, *args, **kwargs):
-    return (ref, storage._get_measures_timeserie(
-        ref.metric,
-        ref.metric.archive_policy.get_aggregation(
-            ref.aggregation, granularity),
-        *args, **kwargs))
+    agg = ref.metric.archive_policy.get_aggregation(
+        ref.aggregation, granularity)
+    try:
+        data = storage.get_aggregated_measures(
+            {ref.metric: [agg]},
+            *args, **kwargs)[ref.metric][agg]
+    except gnocchi_storage.MetricDoesNotExist:
+        data = carbonara.AggregatedTimeSerie(
+            carbonara.Aggregation(ref.aggregation, granularity, None))
+    return (ref, data)
 
 
 def get_measures(storage, references, operations,
@@ -136,10 +141,12 @@ def aggregated(refs_and_timeseries, operations, from_timestamp=None,
     lookup_keys = collections.defaultdict(list)
     for (ref, timeserie) in refs_and_timeseries:
         from_ = (None if from_timestamp is None else
-                 carbonara.round_timestamp(from_timestamp, timeserie.sampling))
-        references[timeserie.sampling].append(ref)
-        lookup_keys[timeserie.sampling].append(ref.lookup_key)
-        series[timeserie.sampling].append(timeserie[from_:to_timestamp])
+                 carbonara.round_timestamp(
+                     from_timestamp, timeserie.aggregation.granularity))
+        references[timeserie.aggregation.granularity].append(ref)
+        lookup_keys[timeserie.aggregation.granularity].append(ref.lookup_key)
+        series[timeserie.aggregation.granularity].append(
+            timeserie[from_:to_timestamp])
 
     result = []
     is_aggregated = False
